@@ -25,9 +25,15 @@ def get_qlPeriod(tenor:str):
     return  ql.Period(number, ql_tenor[prd])
 
 
-def qlSchedule(issue_date: str, maturity: str, period: ql.QuantLib.Period, ql_calendar,
-                business_day, maturity_business_day,
-                date_gen, eom: bool = False):
+
+def qlSchedule(issue_date: str, 
+            maturity: str, 
+            period: ql.QuantLib.Period, 
+            ql_calendar,
+            business_day: BusinessDay, 
+            maturity_business_day: BusinessDay,
+            date_gen: DateGeneration, 
+            eom: bool = False):
     """
     Creates list of dates. 
 
@@ -52,8 +58,14 @@ def qlSchedule(issue_date: str, maturity: str, period: ql.QuantLib.Period, ql_ca
     vdate = datestr_to_qldate(issue_date)
     mdate = datestr_to_qldate(maturity)
     
-    schedule = ql.Schedule(vdate, mdate, period, ql_calendar, business_day,
-                       maturity_business_day, date_gen, eom)
+    schedule = ql.Schedule(vdate, 
+                mdate, 
+                period, 
+                ql_calendar, 
+                ql_business_day[business_day],
+                ql_business_day[maturity_business_day], 
+                ql_date_generation[date_gen], 
+                eom)
     return schedule
 
 
