@@ -12,7 +12,6 @@ def curve_piecewise(value_date: str,
                 par_setting:BondSetting, 
                 par_rates: List[Rate], 
                 cal = None, 
-               
                 method: PiecewiseMethods = PiecewiseMethods.logcubicdiscount):
     
     vdate = datestr_to_qldate(value_date) 
@@ -63,30 +62,20 @@ def calc_curve(value_date: str,
                 country = None, 
                 method: str = "LogCubicDiscount" ):
         
-    
-    rates = []
-    for depo_rate in depo_rates:
-        rate = Rate(**depo_rate)
-        rates.append(rate)
-
-    depo_sett = DepoSetting(**depo_setting)
-
-    parrates = []
-    for par_rate in par_rates:
-        rate = Rate(**par_rate)
-        parrates.append(rate)
-    
-    par_sett = BondSetting(**par_setting)
-        
+    if country:
+        try:
+            calendar = ql_calendar_market[country]
+        except:
+            calendar = None
     t_structure = curve_piecewise(value_date, 
-                depo_sett, 
-                rates, 
-                par_sett, 
-                parrates, 
-                country = country, 
+                depo_setting, 
+                depo_rates, 
+                par_setting, 
+                par_rates, 
+                cal = calendar,
                 method= method)
 
-    day_count = ql_day_count[par_sett.day_count]
+    day_count = ql_day_count[par_setting.day_count]
     tenors = ["1D", "1W", "2W", "3W"]
     tenors_monthly = [ "".join([str(no + 1),"M"]) for no in range(360)]
     all_tenors = tenors + tenors_monthly
@@ -100,13 +89,13 @@ def calc_curve(value_date: str,
     for atenor in all_tenors:
         adate = ql.NullCalendar().advance(vdate, 
                                         ql.Period(atenor),     
-                                        ql_business_day[par_sett.business_day], 
+                                        ql_business_day[par_setting.business_day], 
                                         False)
         if adate <= maxDate:
             day = adate - vdate
             yrs = day_count.yearFraction(vdate, adate)
             compounding = ql.Compounded
-            freq = ql_frequency[par_sett.frequency]
+            freq = ql_frequency[par_setting.frequency]
             
             zero_rate = t_structure.zeroRate(yrs, compounding, freq)
             tenors.append(yrs)
@@ -124,12 +113,12 @@ def calc_curve(value_date: str,
         else:
             break
 
-    zero_set = {"value_date": value_date, "day_count": par_sett.day_count, 
-                "compound": "Compounded", "frequency": par_sett.frequency,
+    zero_set = {"value_date": value_date, "day_count": par_setting.day_count, 
+                "compound": "Compounded", "frequency": par_setting.frequency,
                 "days": days, "dates": dates, "rates": rates}
     zerocurve = ZeroCurve(**zero_set)
 
-    df_set = {"value_date": value_date, "day_count": par_sett.day_count, 
+    df_set = {"value_date": value_date, "day_count": par_setting.day_count, 
             "days": days, "dates": dates, "dfs": dfs}
     discountcurve = DiscountCurve(**df_set)
 
